import {FC, useCallback, useEffect, useState} from "react";
import {ScrollView, View} from "@tarojs/components";
import styles from './list.module.scss'
import Taro from "@tarojs/taro";
import Empty from "@/components/empty/empty";
import Img from "@/components/image/image";
import { SearchApi } from "@/api/search";
import { AtLoadMore } from 'taro-ui'

type Props = {
  name:string
  clear:boolean
}
const SearchList: FC<Props> = ({name,clear}) => {
  const globalData = Taro.getApp().globalData
  const [page, setPage] = useState(1)
  const [brands, setBrands] = useState<any[]>([])
  const [total, setTotal] = useState(0)
  const [text, setText] = useState('')
  const [loading, setLoading] = useState(true)

  useEffect(()=>{
    if(!clear){
      setBrands([])
      setLoading(true)
    }
  },[clear])
  useEffect(() => {
    if(name){
      getData()
    }
  }, [page,name])

  const getData = useCallback(async () => {
    try {
      console.log(name)
      const data = await SearchApi.list(page, 10,name)
      if (page === 1) {
        if (data.data.length < 10) {
          setText('没有更多了~')
        } else {
          setText('上拉加载更多~')
        }
        setBrands([
          ...data.data
        ])
      }else{
        setBrands([
          ...brands,
          ...data.data
        ])
      }
      setTotal(data.total)

    } catch (e) {
    }
    setLoading(false)
  }, [page,name])


  function jumpInfo(id: number,type:string) {
    console.log(type,'type')
    let url = ''
    switch (type){
      case 'brand':
        url = '/pages/preview/brand/info/info';
        break;
      case 'illness':
        url = '/pages/preview/illness/list/list';
        break;
      case 'article':
        url = '/pages/preview/illness/article/article'
        break
      case 'video_record':
        url = '/pages/preview/videoFull/videoFull'
        break
    }
    Taro.navigateTo({url: `${url}?id=${id}`})

  }

  function onScrollToLower(){
      if (brands?.length < total) {
        setPage(page + 1)
        getData().then()
      } else {
        setText('没有更多了~')
      }
  }

  return (
    <ScrollView
      className='scrollview'
      scrollY
      scrollWithAnimation
      style={{height:`${globalData.windowHeight-60-30}px`,paddingBottom:`30px`}}
      onScrollToLower={onScrollToLower}
    >
      { loading && <AtLoadMore status={'loading'}/>}
      {
        brands.length >= 1 && !loading &&
          <>
            {brands.map((d) => <View onClick={() => jumpInfo(d.data.id,d.data.table)} className={styles.box} key={d.data.id}>
              <Img width={128} height={128} src={d.data['@data'].logo} mode='aspectFill' className={styles.image}/>
              <View className={styles.rightBox}>
                <View className='font-weight mb-2 font-28'>{d.data.title}</View>
                <View className={styles.desc}>{d.graphic_introduction}</View>
              </View>
            </View>)
            }
            <View style={{width: '750rpx', textAlign: 'center', color: '#999'}} className="font-28 mt-3">{text}</View>
          </>
      }
      { !loading && brands.length === 0 && <Empty name='空空如也'/>}
    </ScrollView>
  )
}

export default SearchList

